@@ -5,8 +5,9 @@ from typing import NoReturn
 
 class HTTPError(RuntimeError):
     """ base exception used for this module """
-    def __init__(self, message: str) -> NoReturn:
+    def __init__(self, message: str, http_errno: int = 0) -> NoReturn:
         self.message = message
+        self.http_errno = http_errno
 
     def __str__(self):
         return f"{self.errtype}: {self.message}"
@@ -29,5 +30,5 @@ class RequestError(HTTPError):
     description = ("HTTP requests returned an status code 4xx or 5xx, or "
                    "an unexpected status code")
 
-    def __init__(self, message: str) -> NoReturn:
-        super().__init__(message)
\ No newline at end of file
+    def __init__(self, message: str, http_errno: int = 0) -> NoReturn:
+        super().__init__(message, http_errno)
